import React, { useEffect } from "react";
const isReadyStateMatch = (expected) => {
    if (!expected) {
        return true;
    }
    if (typeof expected === "string" && document.readyState === expected) {
        return true;
    }
    return expected.indexOf(document.readyState) !== -1;
};
const useReadyStateEffect = (effect, deps = [], onState = "complete") => {
    useEffect(() => {
        const destructors = [
            () => document.removeEventListener("readystatechange", listener),
        ];
        const listener = () => {
            if (!isReadyStateMatch(onState)) {
                return;
            }
            const destructor = effect();
            if (destructor) {
                destructors.push(destructor);
            }
        };
        listener();
        document.addEventListener("readystatechange", listener);
        return () => destructors.forEach((d) => d());
    }, deps);
};
function VLibras({ forceOnload }) {
    useReadyStateEffect(() => {
        const script = document.createElement("script");
        script.src = "https://vlibras.gov.br/app/vlibras-plugin.js";
        script.async = true;
        const widgetUrl = `https://vlibras.gov.br/app`;
        script.onload = () => {
            // @ts-ignore
            new window.VLibras.Widget(widgetUrl);
            if (forceOnload) {
                // @ts-ignore
                window.onload();
            }
        };
        document.head.appendChild(script);
    }, [forceOnload], "complete");
    return (
    // @ts-ignore
    React.createElement("div", { vw: "true", className: "enabled" },
        React.createElement("div", { "vw-access-button": "true", className: "active" }),
        React.createElement("div", { "vw-plugin-wrapper": "true" },
            React.createElement("div", { className: "vw-plugin-top-wrapper" }))));
}
export default VLibras;
//# sourceMappingURL=index.js.map